<%	'**************************************************************************
	'* Common code for all the playoffs pools.                                *
	'**************************************************************************

	'**************************************************************************
	'* Global variables.                                                      *
	'**************************************************************************

	'Playoff round names.
	dim PlayoffRoundNames
	PlayoffRoundNames = Array("Wild Card Games", "Divisional Playoffs", "Conference Championships", "Super Bowl " & SUPER_BOWL_INFO)

	'**************************************************************************
	'* Functions and subroutines.                                             *
	'**************************************************************************

	'--------------------------------------------------------------------------
	' Returns the string "at" unless the given game is the Super Bowl, in which
	' case the string "vs." is returned.
	'--------------------------------------------------------------------------
	function GetConjunction(gameRound)

		GetConjunction = "at"
		if gameRound = GetPlayoffsRoundCount() then
			GetConjunction = "vs."
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns the name of the conference the team with the given id belongs to.
	'--------------------------------------------------------------------------
	function GetConference(id)

		dim sql, rs

		GetConference = 0
		sql = "SELECT Conference FROM Teams WHERE TeamID = '" & id & "'"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			GetConference = rs.Fields("Conference").Value
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns the number of playoff games in the schedule.
	'--------------------------------------------------------------------------
	function GetPlayoffsGameCount()

		dim sql, rs

		GetPlayoffsGameCount = 0
		sql = "SELECT COUNT(*) AS Total FROM PlayoffsSchedule"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			GetPlayoffsGameCount = rs.Fields("Total").Value
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns the number of completed playoff games (i.e., games with a
	' result).
	'--------------------------------------------------------------------------
	function GetPlayoffsCompletedGameCount()

		dim sql, rs

		GetPlayoffsCompletedGameCount = 0
		sql = "SELECT COUNT(*) AS Total" _
		   & " FROM PlayoffsSchedule" _
		   & " WHERE Result IS NOT NULL"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			GetPlayoffsCompletedGameCount = rs.Fields("Total").Value
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns the number of rounds in the playoff schedule.
	'--------------------------------------------------------------------------
	function GetPlayoffsRoundCount()

		dim sql, rs

		GetPlayoffsRoundCount = 0
		sql = "SELECT MAX(Round) AS Total FROM PlayoffsSchedule"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			GetPlayoffsRoundCount = rs.Fields("Total").Value
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns the date and time of the first playoffs game.
	'--------------------------------------------------------------------------
	function GetPlayoffsStartDateTime()

		dim sql, rs

		GetPlayoffsStartDateTime = ""
		sql = "SELECT * FROM PlayoffsSchedule ORDER BY [DateTime]"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			GetPlayoffsStartDateTime = CDate(rs.Fields("DateTime").Value)
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns true if the given playoff round is locked. 
	'--------------------------------------------------------------------------
	function IsPlayoffsRoundLocked(n)

		dim sql, rs, gameDateTime

		IsPlayoffsRoundLocked = true
		sql = "SELECT * FROM PlayoffsSchedule" _
		  & " WHERE Round = " & n _
		  & " ORDER BY [DateTime]"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			gameDateTime = CDate(rs.Fields("DateTime").Value)
			if gameDateTime > GetCurrentDateTime() then
				IsPlayoffsRoundLocked = false
			end if
		end if

	end function

	'--------------------------------------------------------------------------
	' Set the results for the given playoff game based on the game score and
	' point spread.
	'--------------------------------------------------------------------------
	sub SetPlayoffsGameResults(id)

		dim sql, rs, vid, hid, vscore, hscore, spread, result, atsResult

		sql = "SELECT * FROM PlayoffsSchedule WHERE GameID = " & id
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			vid    = rs.Fields("VisitorID").Value
			hid    = rs.Fields("HomeID").Value
			vscore = rs.Fields("VisitorScore").Value
			hscore = rs.Fields("HomeScore").Value
			spread = rs.Fields("PointSpread").Value

			result = "NULL"
			atsResult = "NULL"

			'If scores are available, determine the results.
			if IsNumeric(vscore) and IsNumeric(hscore) then

				'Find the winner.
				vscore = CInt(vscore)
				hscore = CInt(hscore)
				if vscore > hscore then
					result = vid
				elseif hscore > vscore then
					result = hid
				else
					result = TIE_STR
				end if
				result = "'" & result & "'"

				'Find the winner vs. the spread
				if IsNumeric(spread) then
					spread = CDbl(spread)
				else
					spread = 0
				end if
				if (vscore + spread) > hscore then
					atsResult = vid
				elseif hscore > (vscore + spread) then
					atsResult = hid
				else
					atsResult = TIE_STR
				end if
				atsResult = "'" & atsResult & "'"
			end if

			'Update the results.
			sql = "UPDATE PlayoffsSchedule SET" _
			   & " Result       = " & result & ", " _
			   & " ATSResult    = " & atsResult _
			   & " WHERE GameID = " & id
			call DbConn.Execute(sql)
		end if

	end sub %>
