<%	'**************************************************************************
	'* Common code for the playoffs pick'em pool.                             *
	'**************************************************************************

	'--------------------------------------------------------------------------
	' Returns the number of players who have entries in the playoffs pick'em
	' pool.
	'--------------------------------------------------------------------------
	function GetPlayoffsPickEntryCount()

		dim sql, rs

		GetPlayoffsPickEntryCount = 0
		sql = "SELECT COUNT(DISTINCT Username) AS Total FROM playoffsPicks"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			GetPlayoffsPickEntryCount = rs.Fields("Total").Value
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns the number of correct picks made by the specified user for the
	' playoff games. If the user did not enter any picks, an empty string is
	' returned.
	'--------------------------------------------------------------------------
	function GetPlayoffsPickScore(username)

		dim sql, rs, resultField, tieTotal

		GetPlayoffsPickScore = ""

		'Determine if the user has made an entry.
		sql = "SELECT COUNT(*) AS Total FROM PlayoffsPicks" _
		    & " WHERE Username = '" & SqlEscape(username) & "'"
		set rs = DbConn.Execute(sql)
		if rs.Fields("Total").Value = 0 then
			exit function
		end if

		'Determine which result field to use.
		resultField = "Result"
		if USE_POINT_SPREADS then
			resultField = "ATSResult"
		end if

		'Total the number of correct picks.
		sql = "SELECT COUNT(*) AS Total" _
		    & " FROM PlayoffsPicks, PlayoffsSchedule" _
		    & " WHERE Username = '" & SqlEscape(username) & "'" _
		    & " AND PlayoffsPicks.GameID = PlayoffsSchedule.GameID" _
		    & " AND PlayoffsPicks.Pick = PlayoffsSchedule." & resultField _
		    & " AND PlayoffsSchedule." & resultField & " IS NOT NULL"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			GetPlayoffsPickScore = rs.Fields("Total").Value
		end if

		'If point spreads are used, add a half point for any tied games.
		if USE_POINT_SPREADS then
		sql = "SELECT COUNT(*) AS Total" _
		    & " FROM PlayoffsPicks, PlayoffsSchedule" _
		    & " WHERE Username = '" & SqlEscape(username) & "'" _
		    & " AND PlayoffsPicks.GameID = PlayoffsSchedule.GameID" _
		    & " AND PlayoffsPicks.Pick <> ''" _
		    & " AND PlayoffsSchedule.ATSResult = '" & TIE_STR & "'"
			set rs = DbConn.Execute(sql)
			if not (rs.EOF and rs.BOF) then
				tieTotal = rs.Fields("Total").Value
				if IsNumeric(tieTotal) then
					GetPlayoffsPickScore = GetPlayoffsPickScore + tieTotal / 2
				end if
			end if
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns the confidence score for picks made by the specified user for the
	' playoff games. If the user did not enter any picks, an empty string is
	' returned.
	'--------------------------------------------------------------------------
	function GetPlayoffsConfidenceScore(username)

		dim sql, rs, resultField, tieTotal

		GetPlayoffsConfidenceScore = ""

		'Determine if the user has made an entry.
		sql = "SELECT COUNT(*) AS Total FROM PlayoffsPicks" _
		    & " WHERE Username = '" & SqlEscape(username) & "'"
		set rs = DbConn.Execute(sql)
		if rs.Fields("Total").Value = 0 then
			exit function
		end if

		'Determine which result field to use.
		resultField = "Result"
		if USE_POINT_SPREADS then
			resultField = "ATSResult"
		end if

		'Total the confidence points for each correct pick.
		sql = "SELECT SUM(Confidence) AS Total" _
		    & " FROM PlayoffsPicks, PlayoffsSchedule" _
		    & " WHERE Username = '" & SqlEscape(username) & "'" _
		    & " AND PlayoffsPicks.GameID = PlayoffsSchedule.GameID" _
		    & " AND PlayoffsPicks.Pick = PlayoffsSchedule." & resultField _
		    & " AND PlayoffsSchedule." & resultField & " IS NOT NULL"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			GetPlayoffsConfidenceScore = rs.Fields("Total").Value
			if not IsNumeric(GetPlayoffsConfidenceScore) then
				GetPlayoffsConfidenceScore = 0
			end if
		end if

		'If point spreads are used, add a half points for any tied games.
		if USE_POINT_SPREADS then
		sql = "SELECT SUM(Confidence) AS Total" _
		    & " FROM PlayoffsPicks, PlayoffsSchedule" _
		    & " WHERE Username = '" & SqlEscape(username) & "'" _
		    & " AND PlayoffsPicks.GameID = PlayoffsSchedule.GameID" _
		    & " AND PlayoffsPicks.Pick <> ''" _
		    & " AND PlayoffsSchedule.ATSResult = '" & TIE_STR & "'"
			set rs = DbConn.Execute(sql)
			if not (rs.EOF and rs.BOF) then
				tieTotal = rs.Fields("Total").Value
				if IsNumeric(tieTotal) then
					GetPlayoffsConfidenceScore = GetPlayoffsConfidenceScore + tieTotal / 2
				end if
			end if
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns an array of users currently in the playoffs pick'em pool.
	'--------------------------------------------------------------------------
	function GetPlayoffsPickPlayersList()

		dim list, sql, rs

		GetPlayoffsPickPlayersList = ""

		sql = "SELECT DISTINCT Username FROM PlayoffsPicks" _
		   & " ORDER BY Username"
		set rs = DbConn.Execute(sql)
		do while not rs.EOF
			if not IsArray(list) then
				redim list(0)
			else
				redim preserve list(UBound(list) + 1)
			end if
			list(UBound(list)) = rs.Fields("Username").Value
			rs.MoveNext
		loop
		GetPlayoffsPickPlayersList = list

	end function

	'--------------------------------------------------------------------------
	' Compares scores to determine the winner(s) for the playoffs pool.
	' If the pool has not been concluded or if no players entered, an empty
	' string is returned instead.
	'--------------------------------------------------------------------------
   function GetPlayoffsPickWinnersList()

		dim sql, rs
		dim players, i
		dim highScore, score
		dim list

		GetPlayoffsPickWinnersList = ""

		'Exit if not all games have been completed.
		if GetPlayoffsGameCount() <> GetPlayoffsCompletedGameCount() then
			exit function
		end if

		'Exit if there are no players.
		players = GetPlayoffsPickPlayersList()
		if not IsArray(players) then
			exit function
		end if

		'Initialize current high score.
		highScore = -1

		'Check each player.
		for i = 0 to Ubound(players)
			if USE_CONFIDENCE_POINTS then
				score = GetPlayoffsConfidenceScore(players(i))
			else
				score = GetPlayoffsPickScore(players(i))
			end if
			if IsNumeric(score) then

				'If this player has a higher score, make the player the winner.
				'winner.
				if score > highScore then
					redim list(0)
					list(0) = players(i)
					highScore = score

				'Otherwise, if this player has the same score, add the player
				'to the winners list.
				elseif score = highScore then
					redim preserve list(UBound(list) + 1)
					list(UBound(list)) = players(i)
				end if
			end if
		next

		GetPlayoffsPickWinnersList = list

	end function

	'--------------------------------------------------------------------------
	' Returns true if the given user has entered any picks in the playoffs
	' pool.
	'--------------------------------------------------------------------------
	function InPlayoffsPickPool(username)

		dim sql, rs

		InPlayoffsPickPool = false
		sql = "SELECT COUNT(*) AS Total FROM PlayoffsPicks" _
		   & " WHERE Username = '" & SqlEscape(username) & "'"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			if rs.Fields("Total").Value > 0 then
				InPlayoffsPickPool = true
			end if
		end if

	end function %>
