<%	'**************************************************************************
	'* Common code for the playoffs rank'em pools.                            *
	'**************************************************************************

	'--------------------------------------------------------------------------
	' Returns the number of players who have entries in the playoffs pool.
	'--------------------------------------------------------------------------
	function GetPlayoffsRankEntryCount()

		dim sql, rs

		GetPlayoffsRankEntryCount = 0
		sql = "SELECT COUNT(*) AS Total FROM (SELECT DISTINCT Username FROM PlayoffsRanks)"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			GetPlayoffsRankEntryCount = rs.Fields("Total").Value
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns an array of users currently in the playoffs pool.
	'--------------------------------------------------------------------------
	function GetPlayoffsRankPlayersList()

		dim list, sql, rs

		GetPlayoffsRankPlayersList = ""

		sql = "SELECT DISTINCT Username FROM PlayoffsRanks" _
		   & " ORDER BY Username"
		set rs = DbConn.Execute(sql)
		do while not rs.EOF
			if not IsArray(list) then
				redim list(0)
			else
				redim preserve list(UBound(list) + 1)
			end if
			list(UBound(list)) = rs.Fields("Username").Value
			rs.MoveNext
		loop
		GetPlayoffsRankPlayersList = list

	end function

	'--------------------------------------------------------------------------
	' Returns the confidence score for rankings made by the specified user for
	' the playoff teams. If the user did not enter any rankings, an empty
	' string is returned.
	'--------------------------------------------------------------------------
	function GetPlayoffsRankScore(username)

		dim sql, rs

		GetPlayoffsRankScore = ""

		'Determine if the user has made an entry.
		sql = "SELECT COUNT(*) AS Total FROM PlayoffsRanks" _
		    & " WHERE Username = '" & SqlEscape(username) & "'"
		set rs = DbConn.Execute(sql)
		if rs.Fields("Total").Value = 0 then
			exit function
		end if

		'Total the team confidence points ranking for each game won.
		sql = "SELECT SUM(Confidence) AS Total FROM PlayoffsRanks, PlayoffsSchedule" _
		   & " WHERE Username = '" & SqlEscape(username) & "'" _
		   & " AND Result IS NOT NULL AND TeamID = Result"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			GetPlayoffsRankScore = rs.Fields("Total").Value
			if not IsNumeric(GetPlayoffsRankScore) then
				GetPlayoffsRankScore = 0
			end if
		end if

	end function

	'--------------------------------------------------------------------------
	' Compares scores to determine the winner(s) for the playoffs pool.
	' If the pool has not been concluded or if no players entered, an empty
	' string is returned instead.
	'--------------------------------------------------------------------------
   function GetPlayoffsRankWinnersList()

		dim sql, rs
		dim players, i
		dim highScore, score
		dim list

		GetPlayoffsRankWinnersList = ""

		'Exit if not all games have been completed.
		if GetPlayoffsGameCount() <> GetPlayoffsCompletedGameCount() then
			exit function
		end if

		'Exit if there are no players.
		players = GetPlayoffsRankPlayersList()
		if not IsArray(players) then
			exit function
		end if

		'Initialize current high score.
		highScore = -1

		'Check each player.
		for i = 0 to Ubound(players)
			score = GetPlayoffsRankScore(players(i))
			if IsNumeric(score) then

				'If this player has a higher score, make the player the winner.
				if score > highScore then
					redim list(0)
					list(0) = players(i)
					highScore = score

				'Otherwise, if this player has the same score, add the player
				'to the winners list.
				elseif score = highScore then
					redim preserve list(UBound(list) + 1)
					list(UBound(list)) = players(i)
				end if
			end if
		next

		GetPlayoffsRankWinnersList = list

	end function

	'--------------------------------------------------------------------------
	' Returns true if the given user has entered any picks in the playoffs
	' pool.
	'--------------------------------------------------------------------------
	function InPlayoffsRankPool(username)

		dim sql, rs

		InPlayoffsRankPool = false
		sql = "SELECT COUNT(*) AS Total FROM PlayoffsRanks" _
		   & " WHERE Username = '" & SqlEscape(username) & "'"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			if rs.Fields("Total").Value > 0 then
				InPlayoffsRankPool = true
			end if
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns true if the playoffs teams have been identified.
	'--------------------------------------------------------------------------
	function HavePlayoffsTeams()

		dim sql, rs

		HavePlayoffsTeams = false
		sql = "SELECT COUNT(*) AS Total FROM Teams WHERE PlayoffsSeed IS NOT NULL"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			if rs.Fields("Total").Value = NumberConferences * NumberPlayoffsSeeds then
				HavePlayoffsTeams = true
			end if
		end if

	end function %>

