<%	'**************************************************************************
	'* Common code for the Super Bowl Propositions Pool                       *
	'**************************************************************************

	'**************************************************************************
	'* Functions and subroutines.                                             *
	'**************************************************************************

	'--------------------------------------------------------------------------
	' Returns the number of players who have entries in the Super Bowl pool.
	'--------------------------------------------------------------------------
	function GetSuperBowlEntryCount()

		dim sql, rs

		GetSuperBowlEntryCount = 0
		sql = "SELECT COUNT(*) AS Total FROM (SELECT DISTINCT Username FROM SuperBowlPicks)"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			GetSuperBowlEntryCount = rs.Fields("Total").Value
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns the number of propositions in the Super Bowl pool.
	'--------------------------------------------------------------------------
	function GetSuperBowlPropCount()

		dim sql, rs

		GetSuperBowlPropCount = 0
		sql = "SELECT COUNT(*) AS Total FROM SuperBowlProps"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			GetSuperBowlPropCount = rs.Fields("Total").Value
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns the number of completed Super Bowl propositions (i.e.,
	' propositions with a result).
	'--------------------------------------------------------------------------
	function GetSuperBowlCompletedPropCount()

		dim sql, rs

		GetSuperBowlCompletedPropCount = 0
		sql = "SELECT COUNT(*) AS Total" _
		   & " FROM SuperBowlProps" _
		   & " WHERE Result IS NOT NULL"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			GetSuperBowlCompletedPropCount = rs.Fields("Total").Value
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns the number of correct picks made by the specified user for the
	' Super Bowl. If the user did not enter any picks, an empty string is
	' returned.
	'--------------------------------------------------------------------------
	function GetSuperBowlScore(username)

		dim sql, rs, tieTotal

		GetSuperBowlScore = ""

		'Determine if the user has made an entry.
		if not InSuperBowlPool(username) then
			exit function
		end if

		'Total the number of correct picks.
		sql = "SELECT COUNT(*) AS Total" _
		    & " FROM SuperBowlPicks, SuperBowlProps" _
		    & " WHERE Username = '" & SqlEscape(username) & "'" _
		    & " AND SuperBowlPicks.PropID = SuperBowlProps.PropID" _
		    & " AND SuperBowlPicks.Pick = SuperBowlProps.Result" _
		    & " AND SuperBowlProps.Result IS NOT NULL"
		set rs = DbConn.Execute(sql)
		if rs.EOF and rs.BOF then
			exit function
		end if
		GetSuperBowlScore = rs.Fields("Total").Value

		'Add half points for any propositions where the teams tied.
		sql = "SELECT COUNT(*) AS Total" _
		    & " FROM SuperBowlPicks, SuperBowlProps" _
		    & " WHERE Username = '" & SqlEscape(username) & "'" _
		    & " AND SuperBowlPicks.PropID = SuperBowlProps.PropID" _
		    & " AND SuperBowlPicks.Pick <> ''" _
		    & " AND SuperBowlProps.Result = '" & TIE_STR & "'"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			tieTotal = rs.Fields("Total").Value
			if IsNumeric(tieTotal) then
				GetSuperBowlScore = GetSuperBowlScore + tieTotal / 2
			end if
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns an array of users currently in the Super Bowl pool.
	'--------------------------------------------------------------------------
	function GetSuperBowlPlayersList()

		dim list, sql, rs

		GetSuperBowlPlayersList = ""

		sql = "SELECT DISTINCT Username FROM SuperBowlPicks" _
		   & " ORDER BY Username"
		set rs = DbConn.Execute(sql)
		do while not rs.EOF
			if not IsArray(list) then
				redim list(0)
			else
				redim preserve list(UBound(list) + 1)
			end if
			list(UBound(list)) = rs.Fields("Username").Value
			rs.MoveNext
		loop
		GetSuperBowlPlayersList = list

	end function

	'--------------------------------------------------------------------------
	' Returns a record set containing the Super Bowl propositions.
	'--------------------------------------------------------------------------
	function GetSuperBowlPropsRecordset()

		dim sql

		sql = "SELECT * FROM SuperBowlProps" _
		   & " ORDER BY PropID"
		set GetSuperBowlPropsRecordset = DbConn.Execute(sql)

	end function

	'--------------------------------------------------------------------------
	' Returns a record set containing the record for the Super Bowl game.
	'--------------------------------------------------------------------------
	function SuperBowlScheduleRecordset()

		dim sql

		sql = "SELECT * FROM PlayoffsSchedule" _
		   & " WHERE Round = (SELECT MAX(Round) FROM PlayoffsSchedule)"
		set SuperBowlScheduleRecordset = DbConn.Execute(sql)

	end function

	'--------------------------------------------------------------------------
	' Returns the date of the Super Bowl game.
	'--------------------------------------------------------------------------
	function GetSuperBowlStartDateTime()

		dim rs

		GetSuperBowlStartDateTime = ""
		set rs = SuperBowlScheduleRecordset()
		if not (rs.EOF and rs.BOF) then
			GetSuperBowlStartDateTime = CDate(rs.Fields("DateTime").Value)
		end if

	end function

	'--------------------------------------------------------------------------
	' Compares scores to determine the winner(s) for the Super Bopwl pool.
	' If the pool has not been concluded or if no players entered, an empty
	' string is returned instead.
	'--------------------------------------------------------------------------
   function GetSuperBowlWinnersList()

		dim sql, rs
		dim players, i
		dim highScore, score
		dim list

		GetSuperBowlWinnersList = ""

		'Exit if not all propositions have been determined.
		sql = "SELECT COUNT(*) AS Total FROM SuperBowlProps" _
		  & " WHERE Result IS NULL"
		set rs = DbConn.Execute(sql)
		if rs.EOF and rs.BOF then
			exit function
		elseif rs.Fields("Total").Value > 0 then
			exit function
		end if

		'Exit if there are no players.
		players = GetSuperBowlPlayersList()
		if not IsArray(players) then
			exit function
		end if

		'Initialize current high score.
		highScore = -1

		'Check each player.
		for i = 0 to Ubound(players)
			score = GetSuperBowlScore(players(i))
			if IsNumeric(score) then

				'If this player has a higher score, make the player the winner.
				if score > highScore then
					redim list(0)
					list(0) = players(i)
					highScore = score

				'Otherwise, if this player has the same score, add the
				'player to the winners list.
				elseif score = highScore then
					redim preserve list(UBound(list) + 1)
					list(UBound(list)) = players(i)
				end if
			end if
		next

		GetSuperBowlWinnersList = list

	end function

	'--------------------------------------------------------------------------
	' Returns true if the given user has entered any picks in the Super Bowl
	' pool.
	'--------------------------------------------------------------------------
	function InSuperBowlPool(username)

		dim sql, rs

		InSuperBowlPool = false
		sql = "SELECT COUNT(*) AS Total FROM SuperBowlPicks" _
		   & " WHERE Username = '" & SqlEscape(username) & "'"
		set rs = DbConn.Execute(sql)
		if not (rs.EOF and rs.BOF) then
			if rs.Fields("Total").Value > 0 then
				InSuperBowlPool = true
			end if
		end if

	end function

	'--------------------------------------------------------------------------
	' Returns true if the Super Bowl has started.
	'--------------------------------------------------------------------------
	function IsSuperBowlLocked()

		dim gameDate

		IsSuperBowlLocked = false
		gameDate = GetSuperBowlStartDateTime()
		if gameDate <> "" then
			IsSuperBowlLocked = IsDateTimePast(gameDate)
		end if

	end function %>