 

/*****************************************************************************
 * Create database for the NFL 2011 season.
 *****************************************************************************/


USE master;
GO
CREATE DATABASE FootballPool;
GO

USE FootballPool

/*****************************************************************************
 * Create the tables.
 *****************************************************************************/

DROP TABLE Credits
CREATE TABLE Credits (
    Username VARCHAR(25),
    [Timestamp] DATETIME,
    Amount SMALLMONEY,
    Description VARCHAR(255)
)

DROP TABLE Messages
CREATE TABLE Messages (
    MessageID INT IDENTITY,
    Username VARCHAR(25),
    [Message] VARCHAR(MAX),
    Created DATETIME,
    LastModified DATETIME
)

DROP TABLE News
CREATE TABLE News (
    LineNumber INT NOT NULL,
    Line VARCHAR(MAX)
)

DROP TABLE PaymentNotifications
CREATE TABLE PaymentNotifications (
    [Timestamp] DATETIME,
    Data VARCHAR(Max),
    Response VARCHAR(255)
)

DROP TABLE Users
CREATE TABLE Users (
    Username VARCHAR(25) NOT NULL,
    EmailAddress VARCHAR(255),
    ContactInformation VARCHAR(MAX),
    NotifyOfNewsUpdates BIT,
    NotifyOfScheduleUpdates BIT,
    NotifyOfSpreadUpdates BIT,
    NotifyOfResultUpdates BIT,
    DisableEntries BIT,
    Salt CHAR(8),
    Password CHAR(40),
    TeamThemeID VARCHAR(3),
    TeamRankings VARCHAR(255)
)

DROP TABLE Schedule
CREATE TABLE Schedule (
    GameID INT IDENTITY,
    Week TINYINT,
    [DateTime] DATETIME,
    VisitorID VARCHAR(3),
    VisitorScore TINYINT,
    PointSpread FLOAT,
    HomeID VARCHAR(3),
    HomeScore TINYINT,
    OT BIT,
    Result VARCHAR(3),
    AtsResult VARCHAR(3)
)

DROP TABLE Teams
CREATE TABLE Teams (
    TeamID VARCHAR(3) NOT NULL,
    Conference TINYINT,
    Division TINYINT,
    City VARCHAR(25),
    [Name] VARCHAR(25),
    DisplayName VARCHAR(25),
    PlayoffsSeed TINYINT
)

DROP TABLE WeeklyPicks
CREATE TABLE WeeklyPicks (
    Username VARCHAR(25),
    GameID INT,
    Pick VARCHAR(3),
    Confidence TINYINT
)

DROP TABLE WeeklyScoring
CREATE TABLE WeeklyScoring (
    Week TINYINT,
    Username VARCHAR(25),
    TieBreaker INT,
    PickScore FLOAT,
    ConfidenceScore FLOAT
)

DROP TABLE WeeklyWinners
CREATE TABLE WeeklyWinners (
    Week TINYINT,
    Username VARCHAR(25)
)

DROP TABLE SidePicks
CREATE TABLE SidePicks (
    Username VARCHAR(25),
    Week TINYINT,
    Pick VARCHAR(3),
    SurvivorBuyback BIT,
    MarginScore INT
)

DROP TABLE SurvivorStatus
CREATE TABLE SurvivorStatus (
    Week TINYINT,
    Username VARCHAR(25),
    Completed TINYINT,
    Missed TINYINT,
    Revived TINYINT,
    Buybacks TINYINT,
    WasAlive BIT,
    IsAlive BIT,
    IsPending BIT,
    IsWinner BIT
)

DROP TABLE PlayoffsSchedule
CREATE TABLE PlayoffsSchedule (
    GameID INT IDENTITY,
    [Round] TINYINT,
    [DateTime] DATETIME,
    VisitorID VARCHAR(3),
    VisitorScore TINYINT,
    PointSpread FLOAT,
    HomeID VARCHAR(3),
    HomeScore TINYINT,
    OT TINYINT DEFAULT(0),
    Result VARCHAR(3),
    AtsResult VARCHAR(3)
)

DROP TABLE PlayoffsPicks
CREATE TABLE PlayoffsPicks (
    Username VARCHAR(25),
    GameID INT,
    Pick VARCHAR(3),
    Confidence TINYINT
)

DROP TABLE PlayoffsRanks
CREATE TABLE PlayoffsRanks (
    Username VARCHAR(25),
    TeamID VARCHAR(3),
    Confidence TINYINT
)

DROP TABLE SuperBowlProps
CREATE TABLE SuperBowlProps (
    PropID INT IDENTITY,
    Description VARCHAR(255),
    Header VARCHAR(255),
    Result VARCHAR(3)
)

DROP TABLE SuperBowlPicks
CREATE TABLE SuperBowlPicks (
    Username VARCHAR(25),
    PropID INT,
    Pick VARCHAR(3)
)
/*****************************************************************************
 * Load the User table.
 *
 * Need at least the Admin, password is 'admin'.
 *****************************************************************************/

INSERT INTO Users (Username, Salt, Password) VALUES('Admin', 'hnTg8AcS', '4E36E6E46ED81244998AC13728825F6C14994062')

/*****************************************************************************
 * Load the Teams table.
 *****************************************************************************/

INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('ARI',2,4,'Arizona','Cardinals')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('ATL',2,3,'Atlanta','Falcons')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('BAL',1,2,'Baltimore','Ravens')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('BUF',1,1,'Buffalo','Bills')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('CAR',2,3,'Carolina','Panthers')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('CHI',2,2,'Chicago','Bears')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('CIN',1,2,'Cincinnati','Bengals')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('CLE',1,2,'Cleveland','Browns')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('DAL',2,1,'Dallas','Cowboys')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('DEN',1,4,'Denver','Broncos')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('DET',2,2,'Detroit','Lions')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('GB',2,2,'Green Bay','Packers')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('HOU',1,3,'Houston','Texans')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('IND',1,3,'Indianapolis','Colts')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('JAX',1,3,'Jacksonville','Jaguars')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('KC',1,4,'Kansas City','Chiefs')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('MIA',1,1,'Miami','Dolphins')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('MIN',2,2,'Minnesota','Vikings')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('NE',1,1,'New England','Patriots')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('NO',2,3,'New Orleans','Saints')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('NYG',2,1,'New York','Giants')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('NYJ',1,1,'New York','Jets')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('OAK',1,4,'Oakland','Raiders')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('PHI',2,1,'Philadelphia','Eagles')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('PIT',1,2,'Pittsburgh','Steelers')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('SD',1,4,'San Diego','Chargers')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('SEA',2,4,'Seattle','Seahawks')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('SF',2,4,'San Francisco','49ers')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('STL',2,4,'St. Louis','Rams')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('TB',2,3,'Tampa Bay','Buccaneers')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('TEN',1,3,'Tennessee','Titans')
INSERT INTO Teams (TeamID, Conference, Division, City, [Name]) VALUES('WAS',2,1,'Washington','Redskins')

/*****************************************************************************
 * Load the Schedule table.
 *****************************************************************************/

/*****************************************************************************
 * Load the Schedule table.
 *****************************************************************************/

INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/8/2011 8:30:00 PM','NO','GB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/11/2011 1:00:00 PM','ATL','CHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/11/2011 1:00:00 PM','CIN','CLE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/11/2011 1:00:00 PM','BUF','KC')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/11/2011 1:00:00 PM','PHI','STL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/11/2011 1:00:00 PM','TEN','JAX')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/11/2011 1:00:00 PM','PIT','BAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/11/2011 1:00:00 PM','IND','HOU')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/11/2011 1:00:00 PM','DET','TB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/11/2011 4:15:00 PM','NYG','WAS')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/11/2011 4:15:00 PM','CAR','ARI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/11/2011 4:15:00 PM','MIN','SD')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/11/2011 4:15:00 PM','SEA','SF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/11/2011 8:20:00 PM','DAL','NYJ')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/12/2011 7:00:00 PM','OAK','DEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(1,'9/12/2011 10:15:00 PM','NE','MIA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 1:00:00 PM','KC','DET')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 1:00:00 PM','BAL','TEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 1:00:00 PM','CLE','IND')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 1:00:00 PM','OAK','BUF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 1:00:00 PM','TB','MIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 1:00:00 PM','CHI','NO')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 1:00:00 PM','JAX','NYJ')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 1:00:00 PM','SEA','PIT')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 1:00:00 PM','ARI','WAS')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 4:05:00 PM','GB','CAR')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 4:05:00 PM','DAL','SF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 4:15:00 PM','SD','NE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 4:15:00 PM','CIN','DEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 4:15:00 PM','HOU','MIA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/18/2011 8:20:00 PM','PHI','ATL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(2,'9/19/2011 8:30:00 PM','STL','NYG')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 1:00:00 PM','NE','BUF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 1:00:00 PM','SF','CIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 1:00:00 PM','MIA','CLE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 1:00:00 PM','DEN','TEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 1:00:00 PM','DET','MIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 1:00:00 PM','HOU','NO')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 1:00:00 PM','NYG','PHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 1:00:00 PM','JAX','CAR')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 4:05:00 PM','KC','SD')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 4:05:00 PM','NYJ','OAK')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 4:05:00 PM','BAL','STL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 4:15:00 PM','ARI','SEA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 4:15:00 PM','ATL','TB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 4:15:00 PM','GB','CHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/25/2011 8:20:00 PM','PIT','IND')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(3,'9/26/2011 8:30:00 PM','WAS','DAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 1:00:00 PM','CAR','CHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 1:00:00 PM','BUF','CIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 1:00:00 PM','TEN','CLE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 1:00:00 PM','DET','DAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 1:00:00 PM','WAS','STL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 1:00:00 PM','SF','PHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 1:00:00 PM','MIN','KC')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 1:00:00 PM','NO','JAX')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 1:00:00 PM','PIT','HOU')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 4:05:00 PM','NYG','ARI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 4:05:00 PM','ATL','SEA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 4:15:00 PM','MIA','SD')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 4:15:00 PM','DEN','GB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 4:15:00 PM','NE','OAK')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/2/2011 8:20:00 PM','NYJ','BAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(4,'10/3/2011 8:30:00 PM','IND','TB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(5,'10/9/2011 1:00:00 PM','PHI','BUF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(5,'10/9/2011 1:00:00 PM','KC','IND')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(5,'10/9/2011 1:00:00 PM','ARI','MIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(5,'10/9/2011 1:00:00 PM','SEA','NYG')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(5,'10/9/2011 1:00:00 PM','TEN','PIT')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(5,'10/9/2011 1:00:00 PM','NO','CAR')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(5,'10/9/2011 1:00:00 PM','CIN','JAX')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(5,'10/9/2011 1:00:00 PM','OAK','HOU')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(5,'10/9/2011 4:05:00 PM','TB','SF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(5,'10/9/2011 4:05:00 PM','NYJ','NE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(5,'10/9/2011 4:15:00 PM','SD','ATL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(5,'10/9/2011 8:20:00 PM','GB','DAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(5,'10/10/2011 8:20:00 PM','CHI','DET')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(6,'10/16/2011 1:00:00 PM','CAR','ATL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(6,'10/16/2011 1:00:00 PM','IND','CIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(6,'10/16/2011 1:00:00 PM','SF','DET')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(6,'10/16/2011 1:00:00 PM','STL','GB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(6,'10/16/2011 1:00:00 PM','PHI','WAS')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(6,'10/16/2011 1:00:00 PM','BUF','NYG')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(6,'10/16/2011 1:00:00 PM','JAX','PIT')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(6,'10/16/2011 4:05:00 PM','HOU','BAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(6,'10/16/2011 4:05:00 PM','CLE','OAK')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(6,'10/16/2011 4:15:00 PM','DAL','NE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(6,'10/16/2011 4:15:00 PM','NO','TB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(6,'10/16/2011 8:20:00 PM','MIN','CHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(6,'10/17/2011 8:30:00 PM','MIA','NYJ')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(7,'10/23/2011 1:00:00 PM','SEA','CLE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(7,'10/23/2011 1:00:00 PM','ATL','DET')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(7,'10/23/2011 1:00:00 PM','HOU','TEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(7,'10/23/2011 1:00:00 PM','DEN','MIA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(7,'10/23/2011 1:00:00 PM','SD','NYJ')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(7,'10/23/2011 1:00:00 PM','CHI','TB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(7,'10/23/2011 1:00:00 PM','WAS','CAR')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(7,'10/23/2011 4:05:00 PM','PIT','ARI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(7,'10/23/2011 4:05:00 PM','KC','OAK')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(7,'10/23/2011 4:15:00 PM','GB','MIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(7,'10/23/2011 4:15:00 PM','STL','DAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(7,'10/23/2011 8:20:00 PM','IND','NO')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(7,'10/24/2011 8:30:00 PM','BAL','JAX')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(8,'10/30/2011 1:00:00 PM','IND','TEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(8,'10/30/2011 1:00:00 PM','NO','STL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(8,'10/30/2011 1:00:00 PM','MIA','NYG')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(8,'10/30/2011 1:00:00 PM','MIN','CAR')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(8,'10/30/2011 1:00:00 PM','ARI','BAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(8,'10/30/2011 1:00:00 PM','JAX','HOU')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(8,'10/30/2011 4:05:00 PM','WAS','BAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(8,'10/30/2011 4:05:00 PM','DET','DEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(8,'10/30/2011 4:15:00 PM','NE','PIT')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(8,'10/30/2011 4:15:00 PM','CLE','SF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(8,'10/30/2011 4:15:00 PM','CIN','SEA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(8,'10/30/2011 8:20:00 PM','DAL','PHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(8,'10/31/2011 8:30:00 PM','SD','KC')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/6/2011 1:00:00 PM','NYJ','BUF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/6/2011 1:00:00 PM','SEA','DAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/6/2011 1:00:00 PM','ATL','IND')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/6/2011 1:00:00 PM','MIA','KC')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/6/2011 1:00:00 PM','SF','WAS')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/6/2011 1:00:00 PM','CLE','HOU')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/6/2011 1:00:00 PM','TB','NO')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/6/2011 4:05:00 PM','DEN','OAK')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/6/2011 4:05:00 PM','CIN','TEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/6/2011 4:15:00 PM','NYG','NE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/6/2011 4:15:00 PM','STL','ARI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/6/2011 4:15:00 PM','GB','SD')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/6/2011 8:20:00 PM','BAL','PIT')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(9,'11/7/2011 8:30:00 PM','CHI','PHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/10/2011 8:20:00 PM','OAK','SD')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 1:00:00 PM','NO','ATL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 1:00:00 PM','DET','CHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 1:00:00 PM','PIT','CIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 1:00:00 PM','STL','CLE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 1:00:00 PM','BUF','DAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 1:00:00 PM','JAX','IND')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 1:00:00 PM','DEN','KC')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 1:00:00 PM','WAS','MIA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 1:00:00 PM','ARI','PHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 1:00:00 PM','HOU','TB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 1:00:00 PM','TEN','CAR')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 4:05:00 PM','BAL','SEA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 4:15:00 PM','NYG','SF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/13/2011 8:20:00 PM','NE','NYJ')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(10,'11/14/2011 8:30:00 PM','MIN','GB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/17/2011 8:20:00 PM','NYJ','DEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/20/2011 1:00:00 PM','TEN','ATL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/20/2011 1:00:00 PM','JAX','CLE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/20/2011 1:00:00 PM','CAR','DET')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/20/2011 1:00:00 PM','TB','GB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/20/2011 1:00:00 PM','BUF','MIA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/20/2011 1:00:00 PM','OAK','MIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/20/2011 1:00:00 PM','DAL','WAS')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/20/2011 1:00:00 PM','CIN','BAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/20/2011 4:05:00 PM','ARI','SF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/20/2011 4:05:00 PM','SEA','STL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/20/2011 4:15:00 PM','SD','CHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/20/2011 8:20:00 PM','PHI','NYG')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(11,'11/21/2011 8:30:00 PM','KC','NE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/24/2011 12:30:00 PM','GB','DET')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/24/2011 4:15:00 PM','MIA','DAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/27/2011 8:20:00 PM','SF','BAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/27/2011 1:00:00 PM','MIN','ATL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/27/2011 1:00:00 PM','CLE','CIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/27/2011 1:00:00 PM','TB','TEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/27/2011 1:00:00 PM','CAR','IND')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/27/2011 1:00:00 PM','ARI','STL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/27/2011 1:00:00 PM','BUF','NYJ')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/27/2011 1:00:00 PM','HOU','JAX')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/27/2011 4:05:00 PM','CHI','OAK')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/27/2011 4:05:00 PM','WAS','SEA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/27/2011 4:15:00 PM','NE','PHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/27/2011 4:15:00 PM','DEN','SD')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/27/2011 8:20:00 PM','PIT','KC')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(12,'11/28/1911 8:30:00 PM','NYG','NO')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/1/2011 8:20:00 PM','PHI','SEA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 1:00:00 PM','TEN','BUF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 1:00:00 PM','KC','CHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 1:00:00 PM','BAL','CLE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 1:00:00 PM','OAK','MIA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 1:00:00 PM','DET','NO')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 1:00:00 PM','CAR','TB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 1:00:00 PM','NYJ','WAS')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 1:00:00 PM','ATL','HOU')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 1:00:00 PM','CIN','PIT')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 4:05:00 PM','DEN','MIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 4:15:00 PM','GB','NYG')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 4:15:00 PM','DAL','ARI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 4:15:00 PM','STL','SF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/4/2011 8:20:00 PM','IND','NE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(13,'12/5/2011 8:30:00 PM','SD','JAX')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/8/1911 8:20:00 PM','CLE','PIT')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 1:00:00 PM','HOU','CIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 1:00:00 PM','MIN','DET')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 1:00:00 PM','OAK','GB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 1:00:00 PM','NO','TEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 1:00:00 PM','PHI','MIA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 1:00:00 PM','KC','NYJ')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 1:00:00 PM','NE','WAS')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 1:00:00 PM','ATL','CAR')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 1:00:00 PM','TB','JAX')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 1:00:00 PM','IND','BAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 4:05:00 PM','SF','ARI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 4:05:00 PM','CHI','DEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 4:15:00 PM','BUF','SD')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/11/2011 8:20:00 PM','NYG','DAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(14,'12/12/2011 8:30:00 PM','STL','SEA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/15/2011 8:20:00 PM','JAX','ATL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/17/2011 8:20:00 PM','DAL','TB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/18/2011 1:00:00 PM','MIA','BUF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/18/2011 1:00:00 PM','SEA','CHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/18/2011 1:00:00 PM','TEN','IND')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/18/2011 1:00:00 PM','GB','KC')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/18/2011 1:00:00 PM','CIN','STL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/18/2011 1:00:00 PM','NO','MIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/18/2011 1:00:00 PM','WAS','NYG')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/18/2011 1:00:00 PM','CAR','HOU')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/18/2011 4:05:00 PM','DET','OAK')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/18/2011 4:15:00 PM','NE','DEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/18/2011 4:15:00 PM','NYJ','PHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/18/2011 4:15:00 PM','CLE','ARI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/18/2011 8:20:00 PM','BAL','SD')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(15,'12/19/2011 8:30:00 PM','PIT','SF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/22/2011 8:20:00 PM','HOU','IND')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/24/2011 1:00:00 PM','DEN','BUF')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/24/2011 1:00:00 PM','ARI','CIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/24/2011 1:00:00 PM','MIN','WAS')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/24/2011 1:00:00 PM','TB','CAR')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/24/2011 1:00:00 PM','CLE','BAL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/24/2011 1:00:00 PM','JAX','TEN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/24/2011 1:00:00 PM','OAK','KC')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/24/2011 1:00:00 PM','MIA','NE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/24/2011 1:00:00 PM','NYG','NYJ')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/24/2011 1:00:00 PM','STL','PIT')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/24/2011 4:05:00 PM','SD','DET')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/24/2011 4:15:00 PM','SF','SEA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/25/2011 8:20:00 PM','CHI','GB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(16,'12/26/2011 8:30:00 PM','ATL','NO')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 1:00:00 PM','TB','ATL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 1:00:00 PM','BAL','CIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 1:00:00 PM','PIT','CLE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 1:00:00 PM','DET','GB')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 1:00:00 PM','SF','STL')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 1:00:00 PM','NYJ','MIA')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 1:00:00 PM','CHI','MIN')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 1:00:00 PM','BUF','NE')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 1:00:00 PM','CAR','NO')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 1:00:00 PM','DAL','NYG')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 1:00:00 PM','WAS','PHI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 1:00:00 PM','IND','JAX')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 1:00:00 PM','TEN','HOU')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 4:15:00 PM','SEA','ARI')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 4:15:00 PM','SD','OAK')
INSERT INTO Schedule (Week, [DateTime], VisitorID, HomeID) VALUES(17,'1/1/2012 4:15:00 PM','KC','DEN') 

/*****************************************************************************
 * Load the Playoffs Schedule table.
 *****************************************************************************/

INSERT INTO PlayoffsSchedule ([Round], [DateTime]) VALUES(1,'1/8/2011 4:30:00 PM')
INSERT INTO PlayoffsSchedule ([Round], [DateTime]) VALUES(1,'1/8/2011 8:00:00 PM')
INSERT INTO PlayoffsSchedule ([Round], [DateTime]) VALUES(1,'1/9/2011 1:00:00 PM')
INSERT INTO PlayoffsSchedule ([Round], [DateTime]) VALUES(1,'1/9/2011 4:30:00 PM')
INSERT INTO PlayoffsSchedule ([Round], [DateTime]) VALUES(2,'1/15/2011 4:30:00 PM')
INSERT INTO PlayoffsSchedule ([Round], [DateTime]) VALUES(2,'1/15/2011 8:00:00 PM')
INSERT INTO PlayoffsSchedule ([Round], [DateTime]) VALUES(2,'1/16/2011 1:00:00 PM')
INSERT INTO PlayoffsSchedule ([Round], [DateTime]) VALUES(2,'1/16/2011 4:30:00 PM')
INSERT INTO PlayoffsSchedule ([Round], [DateTime]) VALUES(3,'1/23/2011 3:00:00 PM')
INSERT INTO PlayoffsSchedule ([Round], [DateTime]) VALUES(3,'1/23/2011 6:30:00 PM')
INSERT INTO PlayoffsSchedule ([Round], [DateTime]) VALUES(4,'2/6/2011 6:00:00 PM')

/*****************************************************************************
 * Load the Super Bowl Propositions table.
 *****************************************************************************/

INSERT INTO SuperBowlProps (Description, Header) VALUES('Coin toss winner.','Coin<br />Toss')
INSERT INTO SuperBowlProps (Description, Header) VALUES('First score.','1st<br />Scr')
INSERT INTO SuperBowlProps (Description, Header) VALUES('First touchdown.','1st<br />TD')
INSERT INTO SuperBowlProps (Description, Header) VALUES('First field goal.','1st<br />FG')
INSERT INTO SuperBowlProps (Description, Header) VALUES('First turnover.','1st<br />TO')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most points scored in first quarter.','1Q<br />Pts')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most points scored in second quarter.','2Q<br />Pts')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most points scored in third quarter.','3Q<br />Pts')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most points scored in fourth quarter.','4Q<br />Pts')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most touchdowns.','TDs')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most field goals.','FGs')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most turnovers committed.','TOs')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most first downs.','1st<br />Dns')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most third down conversions.','3rd Dn<br />Cnvs')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most penalties committed.','Pnls')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most sacks on opponent.','Scks')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most rushing yards.','Rush<br />Yds')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most passing yards.','Pass<br />Yds')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Most passing attempts.','Pass<br />Atts')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Total yards.','Tot<br />Yds')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Longest pass completion.','Lng<br />Cmp')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Longest rush.','Lng<br />Rush')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Longest punt or kick return.','Lng<br />Ret')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Longest time of possession.','ToP')
INSERT INTO SuperBowlProps (Description, Header) VALUES('Game winner.','Win')

